.. _index:

Meta documentation
==================

Documentation version: |injected_version|.

This project depends on :ref:`project-one <project-one:index>`. and :ref:`project-two <project-two:index>`.

There are some examples on how to use :ref:`project-one <project-one:examples>`.

You can see the usage page of project two :ref:`here <project-two:usage>`.


Contents
========

.. toctree::
   :maxdepth: 2

   features
